<?xml version="1.0" encoding="UTF-8"?>
<!-- $Id: MARC21slim2DC.xsl,v 1.1 2003/01/06 08:20:27 adam Exp $ -->
<xsl:stylesheet version="1.0"
  xmlns:marc="http://www.loc.gov/MARC21/slim"
  xmlns:items="http://www.koha.org/items"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  exclude-result-prefixes="marc items">
    <xsl:import href="MARC21slimUtils.xsl"/>
    <xsl:output method = "xml" indent="yes" omit-xml-declaration = "yes" />
    <xsl:key name="item-by-status" match="items:item" use="items:status"/>
    <xsl:key name="item-by-status-and-branch" match="items:item" use="concat(items:status, ' ', items:homebranch)"/>

    <xsl:template match="/">
            <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="marc:record">
        <xsl:variable name="leader" select="marc:leader"/>
        <xsl:variable name="leader6" select="substring($leader,7,1)"/>
        <xsl:variable name="leader7" select="substring($leader,8,1)"/>
        <xsl:variable name="biblionumber" select="marc:datafield[@tag=999]/marc:subfield[@code='c']"/>
        <xsl:variable name="isbn" select="marc:datafield[@tag=020]/marc:subfield[@code='a']"/>
        <xsl:variable name="controlField008" select="marc:controlfield[@tag=008]"/>
        <xsl:variable name="typeOf008">
            <xsl:choose>
                <xsl:when test="$leader6='a'">
                    <xsl:choose>
                        <xsl:when test="$leader7='a' or $leader7='c' or $leader7='d' or $leader7='m'">BK</xsl:when>
                        <xsl:when test="$leader7='b' or $leader7='i' or $leader7='s'">CR</xsl:when>
                    </xsl:choose>
                </xsl:when>
                <xsl:when test="$leader6='t'">BK</xsl:when>
                <xsl:when test="$leader6='p'">MX</xsl:when>
                <xsl:when test="$leader6='m'">CF</xsl:when>
                <xsl:when test="$leader6='e' or $leader6='f'">MP</xsl:when>
                <xsl:when test="$leader6='g' or $leader6='k' or $leader6='o' or $leader6='r'">VM</xsl:when>
                <xsl:when test="$leader6='c' or $leader6='d' or $leader6='i' or $leader6='j'">MU</xsl:when>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="controlField008-23" select="substring($controlField008,24,1)"/>
        <xsl:variable name="controlField008-21" select="substring($controlField008,22,1)"/>
        <xsl:variable name="controlField008-22" select="substring($controlField008,23,1)"/>
        <xsl:variable name="controlField008-24" select="substring($controlField008,25,4)"/>
        <xsl:variable name="controlField008-26" select="substring($controlField008,27,1)"/>
        <xsl:variable name="controlField008-29" select="substring($controlField008,30,1)"/>
        <xsl:variable name="controlField008-34" select="substring($controlField008,35,1)"/>
        <xsl:variable name="controlField008-33" select="substring($controlField008,34,1)"/>
        <xsl:variable name="controlField008-30-31" select="substring($controlField008,31,2)"/>

        <xsl:variable name="physicalDescription">
            <xsl:if test="$typeOf008='CF' and marc:controlfield[@tag=007][substring(.,12,1)='a']">
                riformattato digitale
            </xsl:if>
            <xsl:if test="$typeOf008='CF' and marc:controlfield[@tag=007][substring(.,12,1)='b']">
                microfilm digitalizzato
            </xsl:if>
            <xsl:if test="$typeOf008='CF' and marc:controlfield[@tag=007][substring(.,12,1)='d']">
                digitalizzato o altra forma analoga
            </xsl:if>

            <xsl:variable name="check008-23">
                <xsl:if test="$typeOf008='BK' or $typeOf008='MU' or $typeOf008='CR' or $typeOf008='MX'">
                    <xsl:value-of select="true()"></xsl:value-of>
                </xsl:if>
            </xsl:variable>
            <xsl:variable name="check008-29">
                <xsl:if test="$typeOf008='MP' or $typeOf008='VM'">
                    <xsl:value-of select="true()"></xsl:value-of>
                </xsl:if>
            </xsl:variable>
            <xsl:choose>
                <xsl:when test="($check008-23 and $controlField008-23='f') or ($check008-29 and $controlField008-29='f')">
                    Braille
                </xsl:when>
                <xsl:when test="($controlField008-23=' ' and ($leader6='c' or $leader6='d')) or (($typeOf008='BK' or $typeOf008='CR') and ($controlField008-23=' ' or $controlField008='r'))">
                    stampa
                </xsl:when>
                <xsl:when test="$leader6 = 'm' or ($check008-23 and $controlField008-23='s') or ($check008-29 and $controlField008-29='s')">
                    risorsa elettronica
                </xsl:when>
                <xsl:when test="($check008-23 and $controlField008-23='b') or ($check008-29 and $controlField008-29='b')">
                    microfiche
                </xsl:when>
                <xsl:when test="($check008-23 and $controlField008-23='a') or ($check008-29 and $controlField008-29='a')">
                    microfilm
                </xsl:when>
            </xsl:choose>
<!--
            <xsl:if test="marc:datafield[@tag=130]/marc:subfield[@code='h']">
                    <xsl:call-template name="chopBrackets">
                        <xsl:with-param name="chopString">
                            <xsl:value-of select="marc:datafield[@tag=130]/marc:subfield[@code='h']"></xsl:value-of>
                        </xsl:with-param>
                    </xsl:call-template>
            </xsl:if>
            <xsl:if test="marc:datafield[@tag=240]/marc:subfield[@code='h']">
                    <xsl:call-template name="chopBrackets">
                        <xsl:with-param name="chopString">
                            <xsl:value-of select="marc:datafield[@tag=240]/marc:subfield[@code='h']"></xsl:value-of>
                        </xsl:with-param>
                    </xsl:call-template>
            </xsl:if>
            <xsl:if test="marc:datafield[@tag=242]/marc:subfield[@code='h']">
                    <xsl:call-template name="chopBrackets">
                        <xsl:with-param name="chopString">
                            <xsl:value-of select="marc:datafield[@tag=242]/marc:subfield[@code='h']"></xsl:value-of>
                        </xsl:with-param>
                    </xsl:call-template>
            </xsl:if>
            <xsl:if test="marc:datafield[@tag=245]/marc:subfield[@code='h']">
                    <xsl:call-template name="chopBrackets">
                        <xsl:with-param name="chopString">
                            <xsl:value-of select="marc:datafield[@tag=245]/marc:subfield[@code='h']"></xsl:value-of>
                        </xsl:with-param>
                    </xsl:call-template>
            </xsl:if>
            <xsl:if test="marc:datafield[@tag=246]/marc:subfield[@code='h']">
                    <xsl:call-template name="chopBrackets">
                        <xsl:with-param name="chopString">
                            <xsl:value-of select="marc:datafield[@tag=246]/marc:subfield[@code='h']"></xsl:value-of>
                        </xsl:with-param>
                    </xsl:call-template>
            </xsl:if>
            <xsl:if test="marc:datafield[@tag=730]/marc:subfield[@code='h']">
                    <xsl:call-template name="chopBrackets">
                        <xsl:with-param name="chopString">
                            <xsl:value-of select="marc:datafield[@tag=730]/marc:subfield[@code='h']"></xsl:value-of>
                        </xsl:with-param>
                    </xsl:call-template>
            </xsl:if>
            <xsl:for-each select="marc:datafield[@tag=256]/marc:subfield[@code='a']">
                    <xsl:value-of select="."></xsl:value-of>
            </xsl:for-each>
            <xsl:for-each select="marc:controlfield[@tag=007][substring(text(),1,1)='c']">
                <xsl:choose>
                    <xsl:when test="substring(text(),14,1)='a'">
                        access
                    </xsl:when>
                    <xsl:when test="substring(text(),14,1)='p'">
                        preservation
                    </xsl:when>
                    <xsl:when test="substring(text(),14,1)='r'">
                        replacement
                    </xsl:when>
                </xsl:choose>
            </xsl:for-each>
-->
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='c'][substring(text(),2,1)='b']">
                cartuccia con chip di memoria
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='c'][substring(text(),2,1)='c']">
                <img src="/opac-tmpl/prog/famfamfam/silk/cd.png" alt="cartuccia disco ottico del computer" title="cartuccia disco ottico del computer">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='c'][substring(text(),2,1)='j']">
                disco magnetico
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='c'][substring(text(),2,1)='m']">
                disco ottico magnetico
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='c'][substring(text(),2,1)='o']">
                <img src="/opac-tmpl/prog/famfamfam/silk/cd.png" alt="disco ottico" title="disco ottico">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='c'][substring(text(),2,1)='r']">
                <img src="/opac-tmpl/prog/famfamfam/silk/drive_web.png" alt="remoto" title="remoto">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='c'][substring(text(),2,1)='a']">
                cartuccia nastro
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='c'][substring(text(),2,1)='f']">
                cassetta
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='c'][substring(text(),2,1)='h']">
                bobina del nastro
            </xsl:if>

            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='d'][substring(text(),2,1)='a']">
                <img src="/opac-tmpl/prog/famfamfam/silk/world.png" alt="globo celeste" title="globo celeste">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='d'][substring(text(),2,1)='e']">
                <img src="/opac-tmpl/prog/famfamfam/silk/world.png" alt="globo della luna del pianeta terra" title="globo della luna del pianeta terra">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='d'][substring(text(),2,1)='b']">
                <img src="/opac-tmpl/prog/famfamfam/silk/world.png" alt="globo planetario o lunare" title="globo planetario o lunare">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='d'][substring(text(),2,1)='c']">
                <img src="/opac-tmpl/prog/famfamfam/silk/world.png" alt="globo terrestre" title="globo terrestre">
            </xsl:if>

            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='o'][substring(text(),2,1)='o']">
                kit
            </xsl:if>

            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='a'][substring(text(),2,1)='d']">
                atlante
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='a'][substring(text(),2,1)='g']">
                diagramma
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='a'][substring(text(),2,1)='j']">
                mappa
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='a'][substring(text(),2,1)='q']">
                plastico
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='a'][substring(text(),2,1)='k']">
                profilo
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='a'][substring(text(),2,1)='r']">
                immagine di rilevamento
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='a'][substring(text(),2,1)='s']">
                sezione
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='a'][substring(text(),2,1)='y']">
                veduta
            </xsl:if>

            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='h'][substring(text(),2,1)='a']">
                scheda a finestra
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='h'][substring(text(),2,1)='e']">
                microfiche
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='h'][substring(text(),2,1)='f']">
                cassetta di microfiche
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='h'][substring(text(),2,1)='b']">
                microfiche in cartuccia
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='h'][substring(text(),2,1)='c']">
                microfilm in cassetta
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='h'][substring(text(),2,1)='d']">
                microfilm in bobina
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='h'][substring(text(),2,1)='g']">
                micropaco
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='m'][substring(text(),2,1)='c']">
                cartuccia di film
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='m'][substring(text(),2,1)='f']">
                cassetta di film
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='m'][substring(text(),2,1)='r']">
                bobina di film
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='n']">
                <img src="/opac-tmpl/prog/famfamfam/silk/chart_curve.png" alt="carta nautica" title="carta nautica">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='c']">
                collage
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='d']">
                 <img src="/opac-tmpl/prog/famfamfam/silk/pencil.png" alt="disegno" title="disegno">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='o']">
                <img src="/opac-tmpl/prog/famfamfam/silk/note.png" alt="scheda didattica" title="scheda didattica">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='e']">
                <img src="/opac-tmpl/prog/famfamfam/silk/paintbrush.png" alt="dipinto" title="dipinto">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='f']">
                riproduzione fotomeccanica
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='g']">
                negativo fotografico
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='h']">
                stampa fotografica
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='i']">
                <img src="/opac-tmpl/prog/famfamfam/silk/picture.png" alt="immagine" title="immagine">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='j']">
                stampa
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='k'][substring(text(),2,1)='l']">
                disegno tecnico
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='q'][substring(text(),2,1)='q']">
                <img src="/opac-tmpl/prog/famfamfam/silk/script.png" alt="musica notata" title="musica notata">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='g'][substring(text(),2,1)='d']">
                spezzone (una filmina corta che non è in un rullo)
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='g'][substring(text(),2,1)='c']">
                cartuccia di filmina
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='g'][substring(text(),2,1)='o']">
                rotolo di filmina
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='g'][substring(text(),2,1)='f']">
                altri tipi di filmina
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='g'][substring(text(),2,1)='s']">
                <img src="/opac-tmpl/prog/famfamfam/silk/pictures.png" alt="diapositiva" title="diapositiva">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='g'][substring(text(),2,1)='t']">
                trasparente
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='r'][substring(text(),2,1)='r']">
                immagine di rilevamento
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='s'][substring(text(),2,1)='e']">
                cilindro
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='s'][substring(text(),2,1)='q']">
                rullo
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='s'][substring(text(),2,1)='g']">
                audiocartuccia
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='s'][substring(text(),2,1)='s']">
                audiocassetta
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='s'][substring(text(),2,1)='d']">
                <img src="/opac-tmpl/prog/famfamfam/silk/cd.png" alt="registrazioni sonore" title="registrazioni sonore">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='s'][substring(text(),2,1)='t']">
                audiobobina
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='s'][substring(text(),2,1)='i']">
                colonna sonora film
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='s'][substring(text(),2,1)='w']">
                registrazione su filo
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='f'][substring(text(),2,1)='c']">
                Braille
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='f'][substring(text(),2,1)='b']">
                combinazione
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='f'][substring(text(),2,1)='a']">
                Luna
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='f'][substring(text(),2,1)='d']">
                Tattile, senza sistema di scrittura
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='t'][substring(text(),2,1)='c']">
                Braille
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='t'][substring(text(),2,1)='b']">
                <img src="/opac-tmpl/prog/famfamfam/silk/magnifier.png" alt="stampa ingrandita" title="stampa ingrandita">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='t'][substring(text(),2,1)='a']">
                stampa (normale)
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='t'][substring(text(),2,1)='d']">
                testo in raccoglitore a fogli mobili
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='v'][substring(text(),2,1)='c']">
                videocartuccia
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='v'][substring(text(),2,1)='f']">
                VHS / videocassetta
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='v'][substring(text(),2,1)='d']">
                <img src="/opac-tmpl/prog/famfamfam/silk/dvd.png" alt="Videodisco" title="Videodisco">
            </xsl:if>
            <xsl:if test="marc:controlfield[@tag=007][substring(text(),1,1)='v'][substring(text(),2,1)='r']">
                videobobina
            </xsl:if>
<!--
            <xsl:for-each select="marc:datafield[@tag=856]/marc:subfield[@code='q'][string-length(.)>1]">
                    <xsl:value-of select="."></xsl:value-of>
            </xsl:for-each>
            <xsl:for-each select="marc:datafield[@tag=300]">
                    <xsl:call-template name="subfieldSelect">
                        <xsl:with-param name="codes">abce</xsl:with-param>
                    </xsl:call-template>
            </xsl:for-each>
-->
        </xsl:variable>
     	<a><xsl:attribute name="href">/cgi-bin/koha/opac-detail.pl?biblionumber=<xsl:value-of select="$biblionumber"/></xsl:attribute>

        <xsl:if test="marc:datafield[@tag=245]">
        <xsl:for-each select="marc:datafield[@tag=245]">
            <xsl:variable name="title">
                     <xsl:call-template name="subfieldSelect">
                        <xsl:with-param name="codes">a</xsl:with-param>
                    </xsl:call-template>
                    <xsl:if test="marc:subfield[@code='b']">
                        <xsl:text> </xsl:text>
                        <xsl:call-template name="subfieldSelect">
                            <xsl:with-param name="codes">b</xsl:with-param>
                        </xsl:call-template>
                    </xsl:if>
                    <xsl:if test="marc:subfield[@code='h']">
                        <xsl:text> </xsl:text>
                        <xsl:call-template name="subfieldSelect">
                            <xsl:with-param name="codes">h</xsl:with-param>
                        </xsl:call-template>
                    </xsl:if>
                    <xsl:call-template name="subfieldSelect">
                        <xsl:with-param name="codes">fgknps</xsl:with-param>
                     </xsl:call-template>
            </xsl:variable>
            <xsl:variable name="titleChop">
                <xsl:call-template name="chopPunctuation">
                    <xsl:with-param name="chopString">
                        <xsl:value-of select="$title"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:variable>
            <xsl:value-of select="$titleChop"/>
        </xsl:for-each>
        </xsl:if>
    </a>
    <p>

    <xsl:choose>
    <xsl:when test="marc:datafield[@tag=100] or marc:datafield[@tag=110] or marc:datafield[@tag=111] or marc:datafield[@tag=700] or marc:datafield[@tag=710] or marc:datafield[@tag=711]">

    da 
        <xsl:for-each select="marc:datafield[@tag=100 or @tag=700]">
            <xsl:choose>
            <xsl:when test="position()=last()">
                <xsl:call-template name="nameABCDQ"/>.
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="nameABCDQ"/>;
            </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=110 or @tag=710]">
            <xsl:choose>
            <xsl:when test="position()=last()">
                <xsl:call-template name="nameABCDN"/>.
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="nameABCDN"/>;
            </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=111 or @tag=711]">
            <xsl:choose>
            <xsl:when test="position()=last()">
                <xsl:call-template name="nameACDEQ"/>.
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="nameACDEQ"/>;
            </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
    </xsl:when>
    </xsl:choose>
    </p>

    <xsl:if test="marc:datafield[@tag=250]">
	<span class="results_summary">
    <span class="label">Edizione: </span>
            <xsl:for-each select="marc:datafield[@tag=250]">
                    <xsl:call-template name="subfieldSelect">
                        <xsl:with-param name="codes">ab</xsl:with-param>
                    </xsl:call-template>
            </xsl:for-each>
	</span>
    </xsl:if>

    <span class="results_summary">
    <xsl:if test="$typeOf008">
        <span class="label">Tipo: </span>
            <xsl:choose>
                <xsl:when test="$leader6='a'">
                    <xsl:choose>
                        <xsl:when test="$leader7='a' or $leader7='c' or $leader7='d' or $leader7='m'"><img src="/opac-tmpl/prog/famfamfam/silk/book.png" alt="Libro" title="Libro"> Libro</xsl:when>
                        <xsl:when test="$leader7='b' or $leader7='i' or $leader7='s'"><img src="/opac-tmpl/prog/famfamfam/silk/newspaper.png" alt="Seriale" title="Seriale"> Risorse in continuazione</xsl:when>
                    </xsl:choose>
                </xsl:when>
                <xsl:when test="$leader6='t'"><img src="/opac-tmpl/prog/famfamfam/silk/book.png" alt="Libro" title="Libro"> Libro</xsl:when>
                <xsl:when test="$leader6='p'"><img src="/opac-tmpl/prog/famfamfam/silk/report_disk.png" alt="materiale misto" title="materiale misto">Materiale misto</xsl:when>
                <xsl:when test="$leader6='m'"><img src="/opac-tmpl/prog/famfamfam/silk/computer_link.png" alt="computer file" title="computer file"/> Computer file</xsl:when>
                <xsl:when test="$leader6='e' or $leader6='f'"><img src="/opac-tmpl/prog/famfamfam/silk/map.png" alt="mappa" title="mappa"> Materiale cartografico</xsl:when>
                <xsl:when test="$leader6='g' or $leader6='k' or $leader6='o' or $leader6='r'"><img src="/opac-tmpl/prog/famfamfam/silk/film.png" alt="Materiali visivi" title="Materiali visivi"> Materiale visivo</xsl:when>
                <xsl:when test="$leader6='c' or $leader6='d' or $leader6='i' or $leader6='j'"><img src="/opac-tmpl/prog/famfamfam/silk/sound.png" alt="musica" title="musica"> Musica</xsl:when>
            </xsl:choose>
    </xsl:if>
    <xsl:if test="string-length(normalize-space($physicalDescription))">
        <span class="label">; Formato: </span><xsl:copy-of select="$physicalDescription"></xsl:copy-of>
    </xsl:if>

        <xsl:if test="$controlField008-21 or $controlField008-22 or $controlField008-24 or $controlField008-26 or $controlField008-29 or $controlField008-34 or $controlField008-33 or $controlField008-30-31 or $controlField008-33">

        <xsl:if test="$typeOf008='CR'">
        <xsl:if test="$controlField008-21 and $controlField008-21 !='|' and $controlField008-21 !=' '">
        <span class="label">; Tipo di risorsa in continuazione: </span>
        </xsl:if>
            <xsl:choose>
                <xsl:when test="$controlField008-21='d'">
                     <img src="/opac-tmpl/prog/famfamfam/silk/database.png" alt="database" title="database"/>
                </xsl:when>
                <xsl:when test="$controlField008-21='l'">
                    fogli mobili
                </xsl:when>
                <xsl:when test="$controlField008-21='m'">
                    serie monografica
                </xsl:when>
                <xsl:when test="$controlField008-21='n'">
                    giornale
                </xsl:when>
                <xsl:when test="$controlField008-21='p'">
                    periodico
                </xsl:when>
                <xsl:when test="$controlField008-21='w'">
                     <img src="/opac-tmpl/prog/famfamfam/silk/world_link.png" alt="Sito web" title="Sito web">
                </xsl:when>
            </xsl:choose>
        </xsl:if>
        <xsl:if test="$typeOf008='BK' or $typeOf008='CR'">
        <xsl:if test="contains($controlField008-24,'abcdefghijklmnopqrstvwxyz')">
        <span class="label">; Natura dei contenuti: </span>
        </xsl:if>
            <xsl:choose>
                <xsl:when test="contains($controlField008-24,'a')">
                    Riassunti/sommari
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'b')">
                     <img src="/opac-tmpl/prog/famfamfam/silk/text_list_bullets.png" alt="biografia" title="biografia">
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'c')">
                    catalogo
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'d')">
                    dizionario
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'e')">
                    enciclopedia
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'f')">
                    Manuali
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'g')">
                    Articoli legali
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'i')">
                    indice
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'k')">
                    discografia
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'l')">
                    legislazione
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'m')">
                    Tesi
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'n')">
                    studi bibliografici
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'o')">
                    recensioni
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'p')">
                    testi programmati
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'q')">
                    filmografia
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'r')">
                    annuario, elenco
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'s')">
                    statistiche
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'t')">
                     <img src="/opac-tmpl/prog/famfamfam/silk/report.png" alt="report tecnico" title="report tecnico">
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'v')">
                    Casi legali e giurisprudenza commentata
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'w')">
                    Rapporti legali, digest
                </xsl:when>
                <xsl:when test="contains($controlField008-24,'z')">
                    trattati
                </xsl:when>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$controlField008-29='1'">
                    pubblicazione di convegno
                </xsl:when>
            </xsl:choose>
        </xsl:if>
        <xsl:if test="$typeOf008='CF'">
            <xsl:if test="$controlField008-26='a' or $controlField008-26='e' or $controlField008-26='f' or $controlField008-26='g'">
            <span class="label">; Tipo di computer file: </span>
            </xsl:if>
            <xsl:choose>
                <xsl:when test="$controlField008-26='a'">
                    dati numerici
                </xsl:when>
                <xsl:when test="$controlField008-26='e'">
                     <img src="/opac-tmpl/prog/famfamfam/silk/database.png" alt="database" title="database"/>
                </xsl:when>
                <xsl:when test="$controlField008-26='f'">
                     <img src="/opac-tmpl/prog/famfamfam/silk/font.png" alt="set di caratteri" title="set di caratteri"> 
                </xsl:when>
                <xsl:when test="$controlField008-26='g'">
                     <img src="/opac-tmpl/prog/famfamfam/silk/controller.png" alt="gioco" title="gioco">
                </xsl:when>
            </xsl:choose>
        </xsl:if>
        <xsl:if test="$typeOf008='BK'">
            <xsl:if test="(substring($controlField008,25,1)='j') or (substring($controlField008,25,1)='1') or ($controlField008-34='a' or $controlField008-34='b' or $controlField008-34='c' or $controlField008-34='d')">
            <span class="label">; Natura dei contenuti: </span>
            </xsl:if>
            <xsl:if test="substring($controlField008,25,1)='j'">
                brevetto
            </xsl:if>
            <xsl:if test="substring($controlField008,31,1)='1'">
                Festschrift (studi in onore)
            </xsl:if>
            <xsl:if test="$controlField008-34='a' or $controlField008-34='b' or $controlField008-34='c' or $controlField008-34='d'">
                 <img src="/opac-tmpl/prog/famfamfam/silk/user.png" alt="biografia" title="biografia">
            </xsl:if>

            <xsl:if test="$controlField008-33 and $controlField008-33!='|' and $controlField008-33!='u' and $controlField008-33!=' '">
            <span class="label">; Forma letteraria: </span>
            </xsl:if>
            <xsl:choose>
                <xsl:when test="$controlField008-33='0'">
                    non fiction
                </xsl:when>
                <xsl:when test="$controlField008-33='1'">
                    fiction
                </xsl:when> 
                <xsl:when test="$controlField008-33='e'">
                    saggio
                </xsl:when>
                <xsl:when test="$controlField008-33='d'">
                    dramma
                </xsl:when>
                <xsl:when test="$controlField008-33='c'">
                    cartoni animati o fumetti
                </xsl:when>
                <xsl:when test="$controlField008-33='l'">
                    fiction
                </xsl:when>
                <xsl:when test="$controlField008-33='h'">
                    umorismo, satire
                </xsl:when>
                <xsl:when test="$controlField008-33='i'">
                    lettera
                </xsl:when>
                <xsl:when test="$controlField008-33='f'">
                    romanzo
                </xsl:when>
                <xsl:when test="$controlField008-33='j'">
                    racconti
                </xsl:when>
                <xsl:when test="$controlField008-33='s'">
                    conferenze, discorsi
                </xsl:when>
            </xsl:choose>
        </xsl:if> 
        <xsl:if test="$typeOf008='MU' and $controlField008-30-31 and $controlField008-30-31!='||' and $controlField008-30-31!='  '">
            <span class="label">; Forma letteraria: </span> <!-- Literary text for sound recordings -->
            <xsl:if test="contains($controlField008-30-31,'b')">
                biografia
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'c')">
                pubblicazione di convegno
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'d')">
                dramma
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'e')">
                saggio
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'f')">
                fiction
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'o')">
                racconti popolari
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'h')">
                storia
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'k')">
                umorismo, satire
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'m')">
                memorie
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'p')">
                poesia
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'r')">
                prove
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'g')">
                cronache
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'s')">
                musica
            </xsl:if>
            <xsl:if test="contains($controlField008-30-31,'l')">
                conferenze, discorsi
            </xsl:if>
        </xsl:if>
        <xsl:if test="$typeOf008='VM'">
            <span class="label">; Tipologia materiali visivi: </span>
            <xsl:choose>
                <xsl:when test="$controlField008-33='a'">
                    originale d'arte
                </xsl:when>
                <xsl:when test="$controlField008-33='b'">
                    kit
                </xsl:when>
                <xsl:when test="$controlField008-33='c'">
                    Riproduzione d'arte
                </xsl:when>
                <xsl:when test="$controlField008-33='d'">
                    diorama
                </xsl:when>
                <xsl:when test="$controlField008-33='f'">
                    filmina
                </xsl:when>
                <xsl:when test="$controlField008-33='g'">
                    Articoli legali
                </xsl:when>
                <xsl:when test="$controlField008-33='i'">
                    immagine
                </xsl:when>
                <xsl:when test="$controlField008-33='k'">
                    grafica
                </xsl:when>
                <xsl:when test="$controlField008-33='l'">
                    disegno tecnico
                </xsl:when>
                <xsl:when test="$controlField008-33='m'">
                    film
                </xsl:when>
                <xsl:when test="$controlField008-33='n'">
                    carta nautica
                </xsl:when>
                <xsl:when test="$controlField008-33='o'">
                    scheda didattica
                </xsl:when>
                <xsl:when test="$controlField008-33='p'">
                    diapositiva da microscopio
                </xsl:when>
                <xsl:when test="$controlField008-33='q' or marc:controlfield[@tag=007][substring(text(),1,1)='a'][substring(text(),2
,1)='q']">
                    plastico
                </xsl:when>
                <xsl:when test="$controlField008-33='r'">
                    realia
                </xsl:when>
                <xsl:when test="$controlField008-33='s'">
                    diapositiva
                </xsl:when>
                <xsl:when test="$controlField008-33='t'">
                    trasparente
                </xsl:when>
                <xsl:when test="$controlField008-33='v'">
                    videoregistrazione
                </xsl:when>
                <xsl:when test="$controlField008-33='w'">
                    giocattolo
                </xsl:when>
            </xsl:choose>
        </xsl:if>
        </xsl:if> 

    <xsl:if test="($typeOf008='BK' or $typeOf008='CF' or $typeOf008='MU' or $typeOf008='VM') and ($controlField008-22='a' or $controlField008-22='b' or $controlField008-22='c' or $controlField008-22='d' or $controlField008-22='e' or $controlField008-22='g' or $controlField008-22='j' or $controlField008-22='f')">
        <span class="label">; Publico: </span>
        <xsl:choose>
            <xsl:when test="$controlField008-22='a'">
             Prescolastico;
            </xsl:when>
            <xsl:when test="$controlField008-22='b'">
             Primario;
            </xsl:when>
            <xsl:when test="$controlField008-22='c'">
             Pre-adolescente;
            </xsl:when>
            <xsl:when test="$controlField008-22='d'">
             Adolescente;
            </xsl:when>
            <xsl:when test="$controlField008-22='e'">
             Adulti;
            </xsl:when>
            <xsl:when test="$controlField008-22='g'">
             Generale;
            </xsl:when>
            <xsl:when test="$controlField008-22='j'">
             Adolescente;
            </xsl:when>
            <xsl:when test="$controlField008-22='f'">
             Specializzato;
            </xsl:when>
            </xsl:choose>
    </xsl:if>
	</span>

    <xsl:if test="marc:datafield[@tag=260]">
	<span class="results_summary">
    <span class="label">Editore: </span> 
            <xsl:for-each select="marc:datafield[@tag=260]">
                    <xsl:call-template name="subfieldSelect">
                        <xsl:with-param name="codes">bcg</xsl:with-param>
                    </xsl:call-template>
            </xsl:for-each>
	</span>
    </xsl:if>

    <xsl:if test="marc:datafield[@tag=246]">
	<span class="results_summary">
    <span class="label">Altro titolo: </span>
            <xsl:for-each select="marc:datafield[@tag=246]">
                    <xsl:call-template name="subfieldSelect">
                        <xsl:with-param name="codes">ab</xsl:with-param>
                    </xsl:call-template>
            </xsl:for-each>
	</span>

    </xsl:if>

    <span class="results_summary">
			   <span class="label">Disponibile: </span>
			        <xsl:choose>
                        <xsl:when test="marc:datafield[@tag=856]">
                            <xsl:for-each select="marc:datafield[@tag=856]">
                                <xsl:choose>
                                    <xsl:when test="@ind2=0">
                                    <a><xsl:attribute name="href"><xsl:value-of select="marc:subfield[@code='u']"/></xsl:attribute>
                                    <xsl:choose>
                                    <xsl:when test="marc:subfield[@code='y' or @code='3' or @code='z']">
                                        <xsl:call-template name="subfieldSelect">                        
                                        <xsl:with-param name="codes">y3z</xsl:with-param>                    
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:when test="not(marc:subfield[@code='y']) and not(marc:subfield[@code='3']) and not(marc:subfield[@code='z'])">
                                    Clicca qui per l'accesso online
                                    </xsl:when>
                                    </xsl:choose>
                                    </a>
                                    <xsl:choose>
                                    <xsl:when test="position()=last()"></xsl:when>
                                    <xsl:otherwise> | </xsl:otherwise>
                                    </xsl:choose>
                                    </xsl:when> 
                                </xsl:choose>
                            </xsl:for-each>
                        </xsl:when>

				   <xsl:when test="count(key('item-by-status', 'available'))=0 and count(key('item-by-status', 'reference'))=0">Nessuna copia disponibile
				   </xsl:when>
                   <xsl:when test="count(key('item-by-status', 'available'))>0">
                   <span class="available">
                       <b><xsl:text>Copie disponibili per il prestito: </xsl:text></b>
                       <xsl:variable name="available_items"
                           select="key('item-by-status', 'available')"/>
                       <xsl:for-each select="$available_items[generate-id() = generate-id(key('item-by-status-and-branch', concat(items:status, ' ', items:homebranch))[1])]">
                           <xsl:value-of select="items:homebranch"/>
						   <xsl:if test="items:itemcallnumber != '' and items:itemcallnumber">[<xsl:value-of select="items:itemcallnumber"/>]</xsl:if>
                           <xsl:text> (</xsl:text>
                           <xsl:value-of select="count(key('item-by-status-and-branch', concat(items:status, ' ', items:homebranch)))"/>
                           <xsl:text>)</xsl:text>
<xsl:choose><xsl:when test="position()=last()"><xsl:text>. </xsl:text></xsl:when><xsl:otherwise><xsl:text>, </xsl:text></xsl:otherwise></xsl:choose>
                       </xsl:for-each>
                   </span>
                   </xsl:when>
				   </xsl:choose>

                   <xsl:choose>
                   <xsl:when test="count(key('item-by-status', 'reference'))>0">
                   <span class="available">
                       <b><xsl:text>Copie disponibili per consultazione: </xsl:text></b>
                       <xsl:variable name="reference_items"
                           select="key('item-by-status', 'reference')"/>
                       <xsl:for-each select="$reference_items[generate-id() = generate-id(key('item-by-status-and-branch', concat(items:status, ' ', items:homebranch))[1])]">
                           <xsl:value-of select="items:homebranch"/>
						   <xsl:if test="items:itemcallnumber != '' and items:itemcallnumber">[<xsl:value-of select="items:itemcallnumber"/>]</xsl:if>
                           <xsl:text> (</xsl:text>
                           <xsl:value-of select="count(key('item-by-status-and-branch', concat(items:status, ' ', items:homebranch)))"/>
                           <xsl:text>)</xsl:text>
                   <xsl:choose><xsl:when test="position()=last()"><xsl:text>. </xsl:text></xsl:when><xsl:otherwise><xsl:text>, </xsl:text></xsl:otherwise></xsl:choose>
                       </xsl:for-each>
                   </span>
                   </xsl:when>
                   </xsl:choose>

                   <xsl:if test="count(key('item-by-status', 'Checked out'))>0">
                   <span class="unavailable">
                       <xsl:text>Prestato (</xsl:text>
                       <xsl:value-of select="count(key('item-by-status', 'Checked out'))"/>
                       <xsl:text>). </xsl:text>
				   </span>
                   </xsl:if>
                   <xsl:if test="count(key('item-by-status', 'Withdrawn'))>0">
                   <span class="unavailable">
                       <xsl:text>Ritirato (</xsl:text>
                       <xsl:value-of select="count(key('item-by-status', 'Withdrawn'))"/>
                       <xsl:text>). </xsl:text>                   </span>
				   </xsl:if>
                    <xsl:if test="count(key('item-by-status', 'Lost'))>0">
                   <span class="unavailable">
                       <xsl:text>Perso (</xsl:text>
                       <xsl:value-of select="count(key('item-by-status', 'Lost'))"/>
                       <xsl:text>). </xsl:text>                   </span>
				   </xsl:if>
                    <xsl:if test="count(key('item-by-status', 'Damaged'))>0">
                   <span class="unavailable">
                       <xsl:text>Danneggiato (</xsl:text>
                       <xsl:value-of select="count(key('item-by-status', 'Damaged'))"/>
                       <xsl:text>). </xsl:text>                   </span>
                   </xsl:if>
                    <xsl:if test="count(key('item-by-status', 'On order'))>0">
                   <span class="unavailable">
                       <xsl:text>Ordinato (</xsl:text>
                       <xsl:value-of select="count(key('item-by-status', 'On order'))"/>
                       <xsl:text>). </xsl:text>                   </span>
                   </xsl:if>
                    <xsl:if test="count(key('item-by-status', 'In transit'))>0">
                   <span class="unavailable">
                       <xsl:text>In transito (</xsl:text>
                       <xsl:value-of select="count(key('item-by-status', 'In transit'))"/>
                       <xsl:text>). </xsl:text>                   </span>
                   </xsl:if>
               </span>
    </xsl:template>

    <xsl:template name="nameABCDQ">
            <xsl:call-template name="chopPunctuation">
                <xsl:with-param name="chopString">
                    <xsl:call-template name="subfieldSelect">
                        <xsl:with-param name="codes">aq</xsl:with-param>
                    </xsl:call-template>
                </xsl:with-param>
                <xsl:with-param name="punctuation">
                    <xsl:text>:,;/ </xsl:text>
                </xsl:with-param>
            </xsl:call-template>
        <xsl:call-template name="termsOfAddress"/>
    </xsl:template>

    <xsl:template name="nameABCDN">
        <xsl:for-each select="marc:subfield[@code='a']">
                <xsl:call-template name="chopPunctuation">
                    <xsl:with-param name="chopString" select="."/>
                </xsl:call-template>
        </xsl:for-each>
        <xsl:for-each select="marc:subfield[@code='b']">
                <xsl:value-of select="."/>
        </xsl:for-each>
        <xsl:if test="marc:subfield[@code='c'] or marc:subfield[@code='d'] or marc:subfield[@code='n']">
                <xsl:call-template name="subfieldSelect">
                    <xsl:with-param name="codes">cdn</xsl:with-param>
                </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="nameACDEQ">
            <xsl:call-template name="subfieldSelect">
                <xsl:with-param name="codes">acdeq</xsl:with-param>
            </xsl:call-template>
    </xsl:template>

    <xsl:template name="termsOfAddress">
        <xsl:if test="marc:subfield[@code='b' or @code='c']">
            <xsl:call-template name="chopPunctuation">
                <xsl:with-param name="chopString">
                    <xsl:call-template name="subfieldSelect">
                        <xsl:with-param name="codes">bc</xsl:with-param>
                    </xsl:call-template>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="nameDate">
        <xsl:for-each select="marc:subfield[@code='d']">
            <xsl:call-template name="chopPunctuation">
                <xsl:with-param name="chopString" select="."/>
            </xsl:call-template>
        </xsl:for-each>
    </xsl:template>

    <xsl:template name="role">
        <xsl:for-each select="marc:subfield[@code='e']">
                    <xsl:value-of select="."/>
        </xsl:for-each>
        <xsl:for-each select="marc:subfield[@code='4']">
                    <xsl:value-of select="."/>
        </xsl:for-each>
    </xsl:template>

    <xsl:template name="specialSubfieldSelect">
        <xsl:param name="anyCodes"/>
        <xsl:param name="axis"/>
        <xsl:param name="beforeCodes"/>
        <xsl:param name="afterCodes"/>
        <xsl:variable name="str">
            <xsl:for-each select="marc:subfield">
                <xsl:if test="contains($anyCodes, @code) or (contains($beforeCodes,@code) and following-sibling::marc:subfield[@code=$axis]) or (contains($afterCodes,@code) and preceding-sibling::marc:subfield[@code=$axis])">
                    <xsl:value-of select="text()"/>
                    <xsl:text> </xsl:text>
                </xsl:if>
            </xsl:for-each>
        </xsl:variable>
        <xsl:value-of select="substring($str,1,string-length($str)-1)"/>
    </xsl:template>

    <xsl:template name="subtitle">
        <xsl:if test="marc:subfield[@code='b']">
                <xsl:call-template name="chopPunctuation">
                    <xsl:with-param name="chopString">
                        <xsl:value-of select="marc:subfield[@code='b']"/>

                        <!--<xsl:call-template name="subfieldSelect">
                            <xsl:with-param name="codes">b</xsl:with-param>                                 
                        </xsl:call-template>-->
                    </xsl:with-param>
                </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="chopBrackets">
        <xsl:param name="chopString"></xsl:param>
        <xsl:variable name="string">
            <xsl:call-template name="chopPunctuation">
                <xsl:with-param name="chopString" select="$chopString"></xsl:with-param>
            </xsl:call-template>
        </xsl:variable>
        <xsl:if test="substring($string, 1,1)='['">
            <xsl:value-of select="substring($string,2, string-length($string)-2)"></xsl:value-of>
        </xsl:if>
        <xsl:if test="substring($string, 1,1)!='['">
            <xsl:value-of select="$string"></xsl:value-of>
        </xsl:if>
    </xsl:template>

</xsl:stylesheet>
